@@ -2,12 +2,12 @@ from django import forms
 from django.utils.translation import gettext_lazy as _
 from entangled.forms import EntangledModelForm
 
-from djangocms_frontend import settings
 from djangocms_frontend.fields import (
     AttributesFormField,
     ColoredButtonGroup,
     TagTypeFormField,
 )
+from djangocms_frontend.helpers import first_choice
 from djangocms_frontend.models import FrontendUIItem
 from djangocms_frontend.settings import COLOR_STYLE_CHOICES
 
@@ -36,7 +36,7 @@ class BadgeForm(EntangledModelForm):
     badge_context = forms.ChoiceField(
         label=_("Context"),
         choices=COLOR_STYLE_CHOICES,
-        initial=COLOR_STYLE_CHOICES[0][0],
+        initial=first_choice(COLOR_STYLE_CHOICES),
         widget=ColoredButtonGroup(),
     )
     badge_pills = forms.BooleanField(
