@@ -1,6 +1,7 @@
 from copy import copy
 
 from django import forms
+from django.core.exceptions import ValidationError
 from django.utils.translation import gettext_lazy as _
 from entangled.forms import EntangledModelForm
 
@@ -9,10 +10,21 @@ from djangocms_frontend.common.background import BackgroundFormMixin
 from djangocms_frontend.common.responsive import ResponsiveFormMixin
 from djangocms_frontend.common.sizing import SizingFormMixin
 from djangocms_frontend.common.spacing import SpacingFormMixin
-from djangocms_frontend.fields import AttributesFormField, IconGroup, TagTypeFormField
-from djangocms_frontend.helpers import link_to_framework_doc, mark_safe_lazy
+from djangocms_frontend.fields import (
+    AttributesFormField,
+    AutoNumberInput,
+    ButtonGroup,
+    IconGroup,
+    TagTypeFormField,
+)
+from djangocms_frontend.helpers import (
+    first_choice,
+    link_to_framework_doc,
+    mark_safe_lazy,
+)
 from djangocms_frontend.models import FrontendUIItem
 
+from ...common.title import TitleFormMixin
 from .. import grid
 from .constants import (
     GRID_COLUMN_ALIGNMENT_CHOICES,
@@ -27,6 +39,7 @@ mixin_factory = settings.get_forms(grid)
 
 class GridContainerForm(
     mixin_factory("GridContainer"),
+    TitleFormMixin,
     BackgroundFormMixin,
     ResponsiveFormMixin,
     SpacingFormMixin,
@@ -51,11 +64,12 @@ class GridContainerForm(
     container_type = forms.ChoiceField(
         label=_("Container type"),
         choices=GRID_CONTAINER_CHOICES,
-        initial=GRID_CONTAINER_CHOICES[0][0],
+        initial=first_choice(GRID_CONTAINER_CHOICES),
         help_text=mark_safe_lazy(
             _(
-                "Defines if the grid should use fixed width (<code>.container</code>) "
-                "or fluid width (<code>.container-fluid</code>)."
+                "Defines if the grid should use fixed width, "
+                "fluid width or the container should fill the full width without "
+                "margins or padding."
             )
         ),
     )
@@ -64,7 +78,11 @@ class GridContainerForm(
 
 
 class GridRowBaseForm(
-    mixin_factory("GridRow"), ResponsiveFormMixin, SpacingFormMixin, EntangledModelForm
+    mixin_factory("GridRow"),
+    TitleFormMixin,
+    ResponsiveFormMixin,
+    SpacingFormMixin,
+    EntangledModelForm,
 ):
     class Meta:
         model = FrontendUIItem
@@ -102,11 +120,13 @@ class GridRowBaseForm(
         help_text=link_to_framework_doc("GridRow", "horizontal_alignment_link"),
         widget=IconGroup(),
     )
-    gutters = forms.BooleanField(
-        label=_("Remove gutters"),
-        initial=False,
+    gutters = forms.ChoiceField(
+        label=_("Gutters"),
+        initial=settings.EMPTY_CHOICE[0][0],
+        choices=settings.EMPTY_CHOICE + settings.SPACER_SIZE_CHOICES,
         required=False,
-        help_text=_("Removes the marginal gutters from the grid."),
+        help_text=_("To remove all spaces between rows set gutters to 0."),
+        widget=ButtonGroup(attrs=dict(property="text")),
     )
     attributes = AttributesFormField()
     tag_type = TagTypeFormField()
@@ -132,6 +152,8 @@ GridRowForm.Meta.entangled_fields["config"] += extra_fields_column.keys()
 
 class GridColumnBaseForm(
     mixin_factory("GridColumn"),
+    TitleFormMixin,
+    BackgroundFormMixin,
     ResponsiveFormMixin,
     SpacingFormMixin,
     EntangledModelForm,
@@ -162,15 +184,39 @@ class GridColumnBaseForm(
     attributes = AttributesFormField()
     tag_type = TagTypeFormField()
 
+    def clean(self):
+        super().clean()
+        for size in settings.DEVICE_SIZES:
+            if f"{size}_col" in self.cleaned_data:
+                if (
+                    isinstance(self.cleaned_data[f"{size}_col"], str)
+                    and self.cleaned_data[f"{size}_col"].isnumeric()
+                ):
+                    self.cleaned_data[f"{size}_col"] = int(
+                        self.cleaned_data[f"{size}_col"]
+                    )
+            else:
+                raise ValidationError(
+                    _(
+                        'Column size needs to be empty, "auto", or a '
+                        "number between 1 and %(cols)d"
+                    ),
+                    params=dict(cols=GRID_SIZE),
+                    code="invalid_column",
+                )
+
 
 # convert regular text type fields to number
+# col_choices = [(col + 1, str(col + 1)) for col in range(GRID_SIZE)] + [("auto", "Auto")]
 extra_fields_column = {}
 for size in settings.DEVICE_SIZES:
     extra_fields_column[f"{size}_col"] = forms.IntegerField(
         label="col" if size == "xs" else f"col-{size}",
         required=False,
+        initial="",
         min_value=0,
         max_value=GRID_SIZE,
+        widget=AutoNumberInput(),
     )
     extra_fields_column[f"{size}_order"] = forms.IntegerField(
         label="order" if size == "xs" else f"order-{size}",
