@@ -43,7 +43,12 @@ class ImagePlugin(
                     "template",
                     "picture",
                     "external_picture",
-                    ("picture_fluid", "picture_rounded", "picture_thumbnail"),
+                    (
+                        "picture_fluid",
+                        "lazy_loading",
+                        "picture_rounded",
+                        "picture_thumbnail",
+                    ),
                 )
             },
         ),
@@ -59,19 +64,6 @@ class ImagePlugin(
                 ),
             },
         ),
-        (
-            _("Link settings"),
-            {
-                "classes": ("collapse",),
-                "fields": (
-                    (
-                        "external_link",
-                        "internal_link",
-                    ),
-                    "file_link",
-                ),
-            },
-        ),
         (
             _("Cropping settings"),
             {
@@ -84,6 +76,12 @@ class ImagePlugin(
             },
         ),
     ]
+    link_fieldset_position = -1
 
     def get_render_template(self, context, instance, placeholder):
         return f"djangocms_frontend/{settings.framework}/{instance.template}/image.html"
+
+    def render(self, context, instance, placeholder):
+        if instance.config.get("lazy_loading", False):
+            instance.add_attribute("loading", "lazy")
+        return super().render(context, instance, placeholder)
