@@ -11,6 +11,7 @@ from djangocms_frontend import settings
 from ...common.responsive import ResponsiveFormMixin
 from ...common.spacing import MarginFormMixin
 from ...fields import AttributesFormField, TagTypeFormField
+from ...helpers import first_choice
 from ...models import FrontendUIItem
 from ..link.forms import AbstractLinkForm
 
@@ -74,6 +75,7 @@ class ImageForm(
                 "template",
                 "picture",
                 "external_picture",
+                "lazy_loading",
                 "width",
                 "height",
                 "alignment",
@@ -97,7 +99,7 @@ class ImageForm(
     template = forms.ChoiceField(
         label=_("Template"),
         choices=get_templates(),
-        initial=get_templates()[0][0],
+        initial=first_choice(get_templates()),
         widget=forms.HiddenInput if len(get_templates()) < 2 else forms.Select,
     )
     picture = AdminImageFormField(
@@ -115,6 +117,14 @@ class ImageForm(
             "Certain options such as cropping are not applicable to external images."
         ),
     )
+    lazy_loading = forms.BooleanField(
+        label=_("Load lazily"),
+        required=False,
+        help_text=_(
+            "Use for images below the fold. This will load images only if user scrolls them into view. "
+        ),
+    )
+
     width = forms.IntegerField(
         label=_("Width"),
         required=False,
@@ -185,7 +195,7 @@ class ImageForm(
     use_responsive_image = forms.ChoiceField(
         label=_("Use responsive image"),
         choices=RESPONSIVE_IMAGE_CHOICES,
-        initial=RESPONSIVE_IMAGE_CHOICES[0][0],
+        initial=first_choice(RESPONSIVE_IMAGE_CHOICES),
         help_text=_(
             "Uses responsive image technique to choose better image to display based upon screen viewport. "
             "This configuration only applies to uploaded images (external pictures will not be affected). "
