@@ -1,4 +1,5 @@
 import copy
+import decimal
 
 from django.apps import apps
 from django.db.models import ObjectDoesNotExist
@@ -69,23 +70,6 @@ def insert_fields(
     return fs
 
 
-def get_template_path(prefix, template, name):
-    return f"djangocms_frontend/{settings.framework}/{prefix}/{template}/{name}.html"
-
-
-def get_plugin_template(instance, prefix, name, templates):
-    template = getattr(instance, "template", templates[0][0])
-    template_path = get_template_path(prefix, template, name)
-
-    try:
-        select_template([template_path])
-    except TemplateDoesNotExist:
-        # TODO render a warning inside the template
-        template_path = get_template_path(prefix, "default", name)
-
-    return template_path
-
-
 def first_choice(choices):
     for value, verbose in choices:
         if not isinstance(verbose, (tuple, list)):
@@ -97,6 +81,23 @@ def first_choice(choices):
     return None
 
 
+def get_template_path(prefix, template, name):
+    return f"djangocms_frontend/{settings.framework}/{prefix}/{template}/{name}.html"
+
+
+def get_plugin_template(instance, prefix, name, templates):
+    template = getattr(instance, "template", first_choice(templates))
+    template_path = get_template_path(prefix, template, name)
+
+    try:
+        select_template([template_path])
+    except TemplateDoesNotExist:
+        # TODO render a warning inside the template
+        template_path = get_template_path(prefix, "default", name)
+
+    return template_path
+
+
 # use mark_safe_lazy to delay the translation when using mark_safe
 # otherwise they will not be added to /locale/
 # https://docs.djangoproject.com/en/1.11/topics/i18n/translation/#other-uses-of-lazy-in-delayed-translations
@@ -112,3 +113,27 @@ def link_to_framework_doc(ui_item, topic):
             ).format(link=link)
         )
     return None
+
+
+def add_plugin(placeholder, plugin):
+    """CMS version save function to add a plugin to a placeholder"""
+    if hasattr(placeholder, "add_plugin"):  # CMS v4?
+        placeholder.add_plugin(plugin)
+    else:  # CMS < v4
+        if plugin.parent:
+            plugin.position -= plugin.parent.position + 1
+        else:
+            plugin.position = 0
+        plugin.save()
+
+
+def delete_plugin(plugin):
+    """CMS version save function to delete a plugin (and its descendants) from a placeholder"""
+    return plugin.placeholder.delete_plugin(plugin)
+
+
+def coerce_decimal(value):
+    try:
+        return decimal.Decimal(value)
+    except TypeError:
+        return None
