@@ -4,6 +4,7 @@ from django.http import HttpRequest
 
 from djangocms_frontend.contrib.image.cms_plugins import ImagePlugin
 from djangocms_frontend.contrib.image.forms import ImageForm, get_templates
+from djangocms_frontend.helpers import first_choice
 
 from ..fixtures import TestFixture
 from ..helpers import get_filer_image
@@ -32,7 +33,7 @@ class PicturePluginTestCase(TestFixture, CMSTestCase):
         plugin.save()
         self.assertTrue(plugin.is_responsive_image)
 
-        self.page.publish(self.language)
+        self.publish(self.page, self.language)
         with self.login_user_context(self.superuser):
             response = self.client.get(self.request_url)
         self.assertEqual(response.status_code, 200)
@@ -52,7 +53,7 @@ class PicturePluginTestCase(TestFixture, CMSTestCase):
         )
         plugin.initialize_from_form(ImageForm)
         plugin.save()
-        self.page.publish(self.language)
+        self.publish(self.page, self.language)
 
         with self.login_user_context(self.superuser):
             response = self.client.get(self.request_url)
@@ -66,7 +67,7 @@ class PicturePluginTestCase(TestFixture, CMSTestCase):
     def test_image_form(self):
         request = HttpRequest()
         request.POST = {
-            "template": get_templates()[0][0],
+            "template": first_choice(get_templates()),
             "picture": "",
             "external_picture": "https://www.django-cms.com/",
             "use_responsive_image": "yes",
